@@ -5,7 +5,7 @@ allbetas <- function(y, x, pvalue = FALSE, logged = FALSE) {
   n <- length(y)
   my <- sum(y) / n
   m <- colmeans(x)
-  sx <- colVars(x)
+  sx <- colVars(x, suma = n * m)
   be <- r / sx
   a <- my - be * m
 
@@ -16,14 +16,12 @@ allbetas <- function(y, x, pvalue = FALSE, logged = FALSE) {
     } else    rownames(result) <- colnames(x)
 
   } else {
-    sy <- sd(y)
-    rho <- r / ( sqrt(sx) * sy)
-    sqdof <- sqrt(n - 2)
-    stat <- rho * sqdof / sqrt(1 - rho^2)
-    if ( logged ){
-      pvalue <- log(2) + pt( abs(stat), n - 2, lower.tail = FALSE, log.p = TRUE)
-    } else pvalue <- 2 * pt( abs(stat), n - 2, lower.tail = FALSE)
-    result <- cbind(a, be, rho, stat, pvalue)
+    sy <- Var(y)
+    rho2 <- r^2 / (sx * sy)
+    dof <- n - 2
+    stat <- r * dof / (1 - rho2)
+    pvalue <- pf( stat, 1, n - 2, lower.tail = FALSE, log.p = logged)
+    result <- cbind(a, be, r, stat, pvalue)
     if ( is.null( colnames(x) ) ) {
       rownames(result) <- paste("X", 1:ncol(x), sep = "" )
     } else  rownames(result) <- colnames(x)
