@@ -30,8 +30,8 @@ generateFolds <- function(target, nfolds = 10, stratified = T, seed = F) {
 }
 
 knn.cv <- function(folds = NULL, nfolds = 10, stratified = FALSE, seed = FALSE, y, x, k, dist.type = "euclidean", type = "C", 
-				   method = "average", freq.option = 0, pred.ret = FALSE) {
+				   method = "average", freq.option = 0, pred.ret = FALSE, mem.eff = FALSE) {
   if (is.null(folds)) folds <- generateFolds(y, nfolds = nfolds, stratified = stratified, seed = seed) 
-  .Call("Rfast_k_nn_cv",PACKAGE = "Rfast",folds, y, x, k, dist.type, type, method, freq.option, pred.ret)
+  .Call("Rfast_k_nn_cv",PACKAGE = "Rfast",folds, y, x, k, dist.type, type, method, freq.option, pred.ret, mem.eff)
 }
 
