@@ -1,6 +1,6 @@
 kruskaltests <- function(x, ina, logged = FALSE) { 
-  n <- dim(x)[1]
-  R <- apply(x, 2, rank)
+  n <- length(ina)
+  R <- colRanks(x)
   ni <- tabulate(ina)
   up <- colsums( rowsum(R, ina)^2 / ni ) - n * (n + 1)^2 / 4
   down <- colsums(R^2) - n * (n + 1)^2 / 4
