@@ -11,12 +11,11 @@ using namespace Rcpp;
 using namespace arma;
 using namespace std;
 
-double gold_rat2(double n, vec ni, vec ni2, double S, vec hi2, const double tol=1e-07){
+double gold_rat2(double n, vec ni, vec ni2, double S, vec hi2,const int size, const double tol){
   double a = 0, b = 50;
-  const double ratio=2.0/(sqrt(5) + 1);
+  const double ratio=0.618033988749895;
   double x1=b-ratio*b, x2=ratio*b;
-  int size = ni.size();
-  
+
   vec nix1(size),nix2(size), ni2hi2(size);
   nix1 = ni*x1;
   nix2 = ni*x2;
@@ -33,7 +32,7 @@ double gold_rat2(double n, vec ni, vec ni2, double S, vec hi2, const double tol=
       x1=b - ratio * (bmina);
       nix1 = ni*x1;
       f1 = calc_f(nix1, n, ni2hi2, S, x1, size);
-    } 
+    }
     else {
       a=x1;
       bmina = b - a;
@@ -44,6 +43,6 @@ double gold_rat2(double n, vec ni, vec ni2, double S, vec hi2, const double tol=
       f2 = calc_f(nix2, n, ni2hi2, S, x2, size);
     }
   }
-  
+
   return 0.5*(x1+x2);
-} 
+}
