@@ -17,12 +17,13 @@ NumericMatrix stable_sort_col_p(NumericMatrix& x,const bool descend){
   NumericMatrix f(n,p);
   mat xx(x.begin(),n,p,false),ff(f.begin(),n,p,false);
   if(descend){
+  	auto func=std::greater<double>();
     #ifdef _OPENMP
     #pragma omp parallel for
     #endif
     for(int i=0;i<p;++i){
       colvec coli=xx.col(i);
-      stable_sort(coli.begin(),coli.end(),descending_double);
+      stable_sort(coli.begin(),coli.end(),func);
       ff.col(i)=coli;
     }
   }else{
@@ -44,12 +45,13 @@ NumericMatrix stable_sort_row_p(NumericMatrix& x,const bool descend){
   NumericMatrix f(n,p);
   mat xx(x.begin(),n,p,false),ff(f.begin(),n,p,false);
   if(descend){
+  	auto func=std::greater<double>();
     #ifdef _OPENMP
     #pragma omp parallel for
     #endif
     for(int i=0;i<n;++i){
       rowvec rowi=xx.row(i);
-      stable_sort(rowi.begin(),rowi.end(),descending_double);
+      stable_sort(rowi.begin(),rowi.end(),func);
       ff.row(i)=rowi;
     }
   }else{
